@@ -1,6 +1,6 @@
 extern crate pointprocesses;
 extern crate plotlib;
-extern crate serde_json;
+extern crate ndarray;
 
 use plotlib::function;
 use plotlib::scatter;
@@ -8,33 +8,37 @@ use plotlib::style::{Line, Marker, Point};
 use plotlib::view;
 use plotlib::page::Page;
 
-use pointprocesses::event::Event;
 use pointprocesses::variable_poisson;
 
+use ndarray::prelude::*;
+
 use std::fs;
 
+static LINE_COLOR: &str = "#373AC6";
+static MARKER_COLOR: &str = "#1C58CE";
+
 fn main() {
     
     let tmax = 30.0;
     let f: fn(f64) -> f64 = |t| {
         4.0*(30.0 - 0.95*t).ln()*(1.0 + 0.1*(0.5*t).sin())
     };
-    let events: Vec<Event> = variable_poisson(tmax, f, 17.0);
+    let events = variable_poisson(tmax, f, 17.0);
 
-    println!("{}", serde_json::to_string_pretty(&events).unwrap());
+    println!("{:?}", events);
     
     let intens_plot = function::Function::new(f, 0.0, tmax)
-        .style(function::Style::new().colour("#FF720C").width(1.5));
+        .style(function::Style::new().colour(LINE_COLOR).width(1.5));
     
-    let event_data: Vec<(f64,f64)> = events.into_iter()
-        .map(|e: Event| (e.get_timestamp(), e.get_intensity()))
+    let event_data: Vec<(f64,f64)> = events.axis_iter(Axis(0))
+        .map(|ev| (ev[0], ev[1]))
         .collect();
 
     let s = scatter::Scatter::from_slice(&event_data)
         .style(scatter::Style::new()
             .size(2.5)
-            .marker(Marker::Cross)
-            .colour("#1932E8"));
+            .marker(Marker::Circle)
+            .colour(MARKER_COLOR));
     
     let v = view::ContinuousView::new()
         .add(&s)
